==> libdatetime-locale-perl_1.17.orig.tar.gz: DateTime-Locale-1.17/share/it-VA.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E d MMM y G",
    GyMMMd => "d MMM y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E d/M",
    MMM => "LLL",
    MMMEd => "E d MMM",
    "MMMMW-count-one" => "'settimana' W 'di' MMM",
    "MMMMW-count-other" => "'settimana' W 'di' MMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'settimana' w 'del' Y",
    "yw-count-other" => "'settimana' w 'del' Y",
  },
  code => "it-VA",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "lun",
    "mar",
    "mer",
    "gio",
    "ven",
    "sab",
    "dom",
  ],
  day_format_narrow => [
    "L",
    "M",
    "M",
    "G",
    "V",
    "S",
    "D",
  ],
  day_format_wide => [
    "luned\N{U+00ec}",
    "marted\N{U+00ec}",
    "mercoled\N{U+00ec}",
    "gioved\N{U+00ec}",
    "venerd\N{U+00ec}",
    "sabato",
    "domenica",
  ],
  day_stand_alone_abbreviated => [
    "lun",
    "mar",
    "mer",
    "gio",
    "ven",
    "sab",
    "dom",
  ],
  day_stand_alone_narrow => [
    "L",
    "M",
    "M",
    "G",
    "V",
    "S",
    "D",
  ],
  day_stand_alone_wide => [
    "luned\N{U+00ec}",
    "marted\N{U+00ec}",
    "mercoled\N{U+00ec}",
    "gioved\N{U+00ec}",
    "venerd\N{U+00ec}",
    "sabato",
    "domenica",
  ],
  era_abbreviated => [
    "a.C.",
    "d.C.",
  ],
  era_narrow => [
    "aC",
    "dC",
  ],
  era_wide => [
    "avanti Cristo",
    "dopo Cristo",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Italian",
  month_format_abbreviated => [
    "gen",
    "feb",
    "mar",
    "apr",
    "mag",
    "giu",
    "lug",
    "ago",
    "set",
    "ott",
    "nov",
    "dic",
  ],
  month_format_narrow => [
    "G",
    "F",
    "M",
    "A",
    "M",
    "G",
    "L",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "gennaio",
    "febbraio",
    "marzo",
    "aprile",
    "maggio",
    "giugno",
    "luglio",
    "agosto",
    "settembre",
    "ottobre",
    "novembre",
    "dicembre",
  ],
  month_stand_alone_abbreviated => [
    "gen",
    "feb",
    "mar",
    "apr",
    "mag",
    "giu",
    "lug",
    "ago",
    "set",
    "ott",
    "nov",
    "dic",
  ],
  month_stand_alone_narrow => [
    "G",
    "F",
    "M",
    "A",
    "M",
    "G",
    "L",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "gennaio",
    "febbraio",
    "marzo",
    "aprile",
    "maggio",
    "giugno",
    "luglio",
    "agosto",
    "settembre",
    "ottobre",
    "novembre",
    "dicembre",
  ],
  name => "Italian Vatican City",
  native_language => "italiano",
  native_name => "italiano Citt\N{U+00e0} del Vaticano",
  native_script => undef,
  native_territory => "Citt\N{U+00e0} del Vaticano",
  native_variant => undef,
  quarter_format_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1\N{U+00ba} trimestre",
    "2\N{U+00ba} trimestre",
    "3\N{U+00ba} trimestre",
    "4\N{U+00ba} trimestre",
  ],
  quarter_stand_alone_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1\N{U+00ba} trimestre",
    "2\N{U+00ba} trimestre",
    "3\N{U+00ba} trimestre",
    "4\N{U+00ba} trimestre",
  ],
  script => undef,
  territory => "Vatican City",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 32,
}

==> libdatetime-locale-perl_1.24.orig.tar.gz: DateTime-Locale-1.24/share/it-VA.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E d MMM y G",
    GyMMMd => "d MMM y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E d/M",
    MMM => "LLL",
    MMMEd => "E d MMM",
    "MMMMW-count-one" => "'settimana' W 'di' MMMM",
    "MMMMW-count-other" => "'settimana' W 'di' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'settimana' w 'del' Y",
    "yw-count-other" => "'settimana' w 'del' Y",
  },
  code => "it-VA",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "lun",
    "mar",
    "mer",
    "gio",
    "ven",
    "sab",
    "dom",
  ],
  day_format_narrow => [
    "L",
    "M",
    "M",
    "G",
    "V",
    "S",
    "D",
  ],
  day_format_wide => [
    "luned\N{U+00ec}",
    "marted\N{U+00ec}",
    "mercoled\N{U+00ec}",
    "gioved\N{U+00ec}",
    "venerd\N{U+00ec}",
    "sabato",
    "domenica",
  ],
  day_stand_alone_abbreviated => [
    "lun",
    "mar",
    "mer",
    "gio",
    "ven",
    "sab",
    "dom",
  ],
  day_stand_alone_narrow => [
    "L",
    "M",
    "M",
    "G",
    "V",
    "S",
    "D",
  ],
  day_stand_alone_wide => [
    "luned\N{U+00ec}",
    "marted\N{U+00ec}",
    "mercoled\N{U+00ec}",
    "gioved\N{U+00ec}",
    "venerd\N{U+00ec}",
    "sabato",
    "domenica",
  ],
  era_abbreviated => [
    "a.C.",
    "d.C.",
  ],
  era_narrow => [
    "aC",
    "dC",
  ],
  era_wide => [
    "avanti Cristo",
    "dopo Cristo",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Italian",
  month_format_abbreviated => [
    "gen",
    "feb",
    "mar",
    "apr",
    "mag",
    "giu",
    "lug",
    "ago",
    "set",
    "ott",
    "nov",
    "dic",
  ],
  month_format_narrow => [
    "G",
    "F",
    "M",
    "A",
    "M",
    "G",
    "L",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "gennaio",
    "febbraio",
    "marzo",
    "aprile",
    "maggio",
    "giugno",
    "luglio",
    "agosto",
    "settembre",
    "ottobre",
    "novembre",
    "dicembre",
  ],
  month_stand_alone_abbreviated => [
    "gen",
    "feb",
    "mar",
    "apr",
    "mag",
    "giu",
    "lug",
    "ago",
    "set",
    "ott",
    "nov",
    "dic",
  ],
  month_stand_alone_narrow => [
    "G",
    "F",
    "M",
    "A",
    "M",
    "G",
    "L",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "gennaio",
    "febbraio",
    "marzo",
    "aprile",
    "maggio",
    "giugno",
    "luglio",
    "agosto",
    "settembre",
    "ottobre",
    "novembre",
    "dicembre",
  ],
  name => "Italian Vatican City",
  native_language => "italiano",
  native_name => "italiano Citt\N{U+00e0} del Vaticano",
  native_script => undef,
  native_territory => "Citt\N{U+00e0} del Vaticano",
  native_variant => undef,
  quarter_format_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1\N{U+00ba} trimestre",
    "2\N{U+00ba} trimestre",
    "3\N{U+00ba} trimestre",
    "4\N{U+00ba} trimestre",
  ],
  quarter_stand_alone_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1\N{U+00ba} trimestre",
    "2\N{U+00ba} trimestre",
    "3\N{U+00ba} trimestre",
    "4\N{U+00ba} trimestre",
  ],
  script => undef,
  territory => "Vatican City",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 35,
}
